========
Overview
========

CUMULATOR — a tool to quantify and report the carbon footprint of Machine Learning computations and communication in academia and healthcare

Aim
___
Raise awareness about the carbon footprint of machine learning methods and to encourage further optimization and the rationale use of AI-powered tools.
This work advocates for sustainable AI and the rational use of IT systems.

Installation
============

Use the following command:

    pip install cumulator
    
Project Structure
=================
    ├── src/cumulator         <- code base for CUMULATOR
        ├── base.py           <- implementation of the Cumulator class
        ├── bonus.py          <- Impact Statement Protocol

Use cases
=========
Cumulator was integrated within the Alg-E platform 

ChangeLog
=========
* 07.06.2020: 0.0.2 added communication costs and cleaned src/
* 21.05.2020: 0.0.1 deployment on PypI and integration with Alg-E

Links
=====
* Project's material: https://drive.google.com/file/d/1saRzSZ_bDqN85a7OoU5611v6BZpz1arx/view?usp=sharing
* GitHub: https://github.com/tristantreb/cumulator
* PyPI: https://pypi.org/project/cumulator/

* Free software: MIT license
